@@ -1,9 +1,11 @@
+"""The main class for modeling. Provides model construction and inspection tools."""
+
 from __future__ import annotations
 
 import itertools as it
 import subprocess
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Union, cast
 
 import libsbml
 import numpy as np
@@ -154,6 +156,7 @@ class Model(_AbstractRateModel):
         stoichiometries: Dict[str, dict] = None,
         functions: Dict[str, Callable] = None,
     ) -> None:
+        """Some docstring"""
         if compounds is not None:
             self.add_compounds(compounds)
         if parameters is not None:
@@ -175,6 +178,7 @@ class Model(_AbstractRateModel):
         stoichiometries: Dict[str, dict] = None,
         functions: Dict[str, Callable] = None,
     ) -> None:
+        """Some docstring"""
         if parameters is not None:
             self.update_parameters(parameters)
         if algebraic_modules is not None:
@@ -195,6 +199,7 @@ class Model(_AbstractRateModel):
         stoichiometries: List[str] = None,
         functions: List[str] = None,
     ) -> None:
+        """Some docstring"""
         if compounds is not None:
             self.remove_compounds(compounds)
         if parameters is not None:
@@ -277,22 +282,33 @@ class Model(_AbstractRateModel):
         args: List[str],
         reversible: bool = False,
     ) -> None:
+        """Some docstring"""
         modifiers = []
         parameters = []
+        dynamic_variables = []
         for i in args:
             if i in self.parameters:
                 parameters.append(i)
             elif i not in stoichiometry:
                 modifiers.append(i)
-        self.add_reaction(
+                dynamic_variables.append(i)
+            else:
+                dynamic_variables.append(i)
+        substrates = [k for k, v in stoichiometry.items() if v < 0]
+        products = [k for k, v in stoichiometry.items() if v > 0]
+
+        self.add_rate(
             rate_name=rate_name,
             function=function,
-            stoichiometry=stoichiometry,
+            substrates=substrates,
+            products=products,
             modifiers=modifiers,
             parameters=parameters,
+            dynamic_variables=dynamic_variables,
             args=args,
             reversible=reversible,
         )
+        self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
     def update_reaction(
         self,
@@ -336,6 +352,7 @@ class Model(_AbstractRateModel):
             self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
     def update_reactions(self, reactions: dict) -> None:
+        """Some docstring"""
         for rate_name, reaction in reactions.items():
             self.update_reaction(rate_name, **reaction)
 
@@ -407,7 +424,7 @@ class Model(_AbstractRateModel):
 
     def get_full_concentration_dict(
         self,
-        y: Union[Dict[str, float], List[float], np.ndarray],
+        y: Union[Dict[str, float], Dict[str, np.ndarray], List[float], np.ndarray],
         t: Union[float, List[float], np.ndarray] = 0.0,
     ) -> Dict[str, np.ndarray]:
         """Calculate the derived variables (at time(s) t).
@@ -438,8 +455,7 @@ class Model(_AbstractRateModel):
         ones = np.ones(len(fcd["time"]))
         if len(fcd["time"]) == 1:
             return {k: ones * v for k, v in self._get_fluxes(fcd=fcd).items()}  # type: ignore
-        else:
-            return {k: ones * v for k, v in self._get_fluxes_array(fcd=fcd).items()}  # type: ignore
+        return {k: ones * v for k, v in self._get_fluxes_array(fcd=fcd).items()}  # type: ignore
 
     def get_fluxes_array(
         self,
@@ -447,7 +463,7 @@ class Model(_AbstractRateModel):
         t: Union[float, List[float], np.ndarray] = 0.0,
     ) -> np.ndarray:
         """Calculate the fluxes at time point(s) t."""
-        return np.array([i for i in self.get_fluxes_dict(y=y, t=t).values()]).T
+        return np.array(list(self.get_fluxes_dict(y=y, t=t).values())).T
 
     def get_fluxes_df(
         self,
@@ -650,10 +666,9 @@ class Model(_AbstractRateModel):
             )
         )
         if linted:
-            blacked_string = subprocess.run(["black", "-c", model_string], stdout=subprocess.PIPE)
+            blacked_string = subprocess.run(["black", "-c", model_string], stdout=subprocess.PIPE, check=True)
             return blacked_string.stdout.decode("utf-8")
-        else:
-            return model_string
+        return model_string
 
     ##########################################################################
     # SBML functions
@@ -697,6 +712,6 @@ class Model(_AbstractRateModel):
         self._create_sbml_compartments(sbml_model=sbml_model)
         self._create_sbml_compounds(sbml_model=sbml_model)
         if bool(self.algebraic_modules):
-            self._create_sbml_algebraic_modules(sbml_model=sbml_model)
+            self._create_sbml_algebraic_modules(_sbml_model=sbml_model)
         self._create_sbml_reactions(sbml_model=sbml_model)
         return doc
