@@ -7,7 +7,6 @@ from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union, cast
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-from pandas.core.frame import DataFrame
 
 from ...utils.plotting import plot, plot_grid
 from ..integrators import AbstractIntegrator as _AbstractIntegrator
@@ -42,7 +41,6 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             y=self.y0,
             v_ss=self.model._v_ss,
             external_label=self.model._external_label,
-            t=0,
         )
         self.model.get_right_hand_side(
             y_labels=self.y0,
@@ -75,6 +73,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         external_label: float = 1.0,
         test_run: bool = True,
     ) -> None:
+        """Some docstring"""
         self.model._y_ss = y_ss
         self.model._v_ss = v_ss
         self.model._external_label = external_label
@@ -112,8 +111,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         res = self.get_results_df(concatenated=True)
         if res is None:
             return None
-        else:
-            res = cast(pd.DataFrame, res)
+        res = cast(pd.DataFrame, res)
         return cast(np.ndarray, res.loc[:, compounds].values)
 
     def plot_label_distribution(
@@ -175,7 +173,6 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         figure_title: Optional[str] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: Optional[plt.Axes] = None,
         figure_kwargs: Optional[Dict[str, Any]] = None,
         subplot_kwargs: Optional[Dict[str, Any]] = None,
         plot_kwargs: Optional[Dict[str, Any]] = None,
@@ -207,7 +204,6 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             plot_titles=plot_titles,
             grid=grid,
             tight_layout=tight_layout,
-            ax=ax,
             figure_kwargs=figure_kwargs,
             subplot_kwargs=subplot_kwargs,
             plot_kwargs=plot_kwargs,
@@ -230,7 +226,6 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         figure_title: Optional[str] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: Optional[plt.Axes] = None,
         figure_kwargs: Optional[Dict[str, Any]] = None,
         subplot_kwargs: Optional[Dict[str, Any]] = None,
         plot_kwargs: Optional[Dict[str, Any]] = None,
@@ -264,7 +259,6 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             plot_titles=plot_titles,
             grid=grid,
             tight_layout=tight_layout,
-            ax=ax,
             figure_kwargs=figure_kwargs,
             subplot_kwargs=subplot_kwargs,
             plot_kwargs=plot_kwargs,
