@@ -2,12 +2,12 @@
 from __future__ import annotations
 
 import math
-from typing import Any, Dict, List, Optional, Tuple, Union, cast
+from typing import Dict, List, Optional, Tuple, Union
 
-import matplotlib.cm as cm
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+from matplotlib import cm
 from matplotlib.collections import QuadMesh
 from tqdm.auto import tqdm
 
@@ -225,32 +225,6 @@ def get_response_coefficients(
     return np.atleast_1d(np.squeeze(conc_resp_coef)), np.atleast_1d(np.squeeze(flux_resp_coef))
 
 
-def get_concentration_response_coefficient(
-    model: Model,
-    parameter: str,
-    y: Dict[str, float],
-    normalized: bool = True,
-    displacement: float = _DISPLACEMENT,
-) -> Optional[np.ndarray]:
-    """Get response of the steady state concentrations to a change of the given parameter."""
-    return get_response_coefficients(
-        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
-    )[0]
-
-
-def get_flux_response_coefficient(
-    model: Model,
-    parameter: str,
-    y: Dict[str, float],
-    normalized: bool = True,
-    displacement: float = _DISPLACEMENT,
-) -> Optional[np.ndarray]:
-    """Get response of the steady state fluxes to a change of the given parameter."""
-    return get_response_coefficients(
-        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
-    )[1]
-
-
 def get_response_coefficients_array(
     model: Model,
     parameters: List[str],
@@ -258,6 +232,7 @@ def get_response_coefficients_array(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
 ) -> Tuple[np.ndarray, np.ndarray]:
+    """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     crcs = np.full(shape=(len(parameters), len(model.get_all_compounds())), fill_value=np.nan)
     frcs = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
     for i, parameter in tqdm(enumerate(parameters), total=len(parameters)):
@@ -275,40 +250,6 @@ def get_response_coefficients_array(
     return crcs, frcs
 
 
-def get_concentration_response_coefficients_array(
-    model: Model,
-    parameters: List[str],
-    y: Dict[str, float],
-    normalized: bool = True,
-    displacement: float = _DISPLACEMENT,
-) -> np.ndarray:
-    """Get response of the steady state concentrations to a change of the given parameters."""
-    return get_response_coefficients_array(
-        model=model,
-        parameters=parameters,
-        y=y,
-        normalized=normalized,
-        displacement=displacement,
-    )[0]
-
-
-def get_flux_response_coefficients_array(
-    model: Model,
-    parameters: List[str],
-    y: Dict[str, float],
-    normalized: bool = True,
-    displacement: float = _DISPLACEMENT,
-) -> np.ndarray:
-    """Get response of the steady state fluxes to a change of the given parameters."""
-    return get_response_coefficients_array(
-        model=model,
-        parameters=parameters,
-        y=y,
-        normalized=normalized,
-        displacement=displacement,
-    )[1]
-
-
 def get_response_coefficients_df(
     model: Model,
     parameters: List[str],
@@ -316,7 +257,7 @@ def get_response_coefficients_df(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
-    """Get response of the steady state concentrations to a change of the given parameters"""
+    """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     crcs, frcs = get_response_coefficients_array(
         model=model,
         parameters=parameters,
@@ -337,6 +278,36 @@ def get_response_coefficients_df(
     return crcs_df, frcs_df
 
 
+def get_concentration_response_coefficient(
+    model: Model,
+    parameter: str,
+    y: Dict[str, float],
+    normalized: bool = True,
+    displacement: float = _DISPLACEMENT,
+) -> Optional[np.ndarray]:
+    """Get response of the steady state concentrations to a change of the given parameter."""
+    return get_response_coefficients(
+        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
+    )[0]
+
+
+def get_concentration_response_coefficients_array(
+    model: Model,
+    parameters: List[str],
+    y: Dict[str, float],
+    normalized: bool = True,
+    displacement: float = _DISPLACEMENT,
+) -> np.ndarray:
+    """Get response of the steady state concentrations to a change of the given parameters."""
+    return get_response_coefficients_array(
+        model=model,
+        parameters=parameters,
+        y=y,
+        normalized=normalized,
+        displacement=displacement,
+    )[0]
+
+
 def get_concentration_response_coefficients_df(
     model: Model,
     parameters: List[str],
@@ -354,6 +325,36 @@ def get_concentration_response_coefficients_df(
     )[0]
 
 
+def get_flux_response_coefficient(
+    model: Model,
+    parameter: str,
+    y: Dict[str, float],
+    normalized: bool = True,
+    displacement: float = _DISPLACEMENT,
+) -> Optional[np.ndarray]:
+    """Get response of the steady state fluxes to a change of the given parameter."""
+    return get_response_coefficients(
+        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
+    )[1]
+
+
+def get_flux_response_coefficients_array(
+    model: Model,
+    parameters: List[str],
+    y: Dict[str, float],
+    normalized: bool = True,
+    displacement: float = _DISPLACEMENT,
+) -> np.ndarray:
+    """Get response of the steady state fluxes to a change of the given parameters."""
+    return get_response_coefficients_array(
+        model=model,
+        parameters=parameters,
+        y=y,
+        normalized=normalized,
+        displacement=displacement,
+    )[1]
+
+
 def get_flux_response_coefficients_df(
     model: Model,
     parameters: List[str],
@@ -387,6 +388,10 @@ def plot_coefficient_heatmap(
     ax: plt.Axes = None,
     cax: plt.Axes = None,
 ) -> Tuple[plt.Figure, plt.Axes, QuadMesh]:
+    """Plot the DataFrame of a response coefficient as a heatmap.
+
+    Use the rows and columns arguments to only plot a subset of the data.
+    """
     df = df.T.round(2)
     if rows is None:
         rows = df.index
@@ -418,6 +423,12 @@ def plot_multiple(
     colorbar: bool = True,
     figsize: Tuple[int, int] = None,
 ) -> Tuple[plt.Figure, np.ndarray]:
+    """Plot multiple heatmaps of the response coefficient DataFrames.
+
+    See also
+    --------
+    plot_coefficient_heatmap
+    """
     vmin = min(i.values.min() for i in dfs)
     vmax = max(i.values.max() for i in dfs)
 
@@ -470,7 +481,13 @@ def plot_concentration_response_coefficients(
     ax: plt.Axes = None,
     cax: plt.Axes = None,
 ) -> Tuple[plt.Figure, plt.Axes, QuadMesh]:
-    """Plot response of the steady state concentration to a change of the given parameters."""
+    """Calculate and plot response of the steady state concentration to a change of the given parameters.
+
+    See also
+    --------
+    get_concentration_response_coefficients_df
+    plot_coefficient_heatmap
+    """
     df = get_concentration_response_coefficients_df(
         model=model,
         parameters=parameters,
@@ -513,7 +530,13 @@ def plot_flux_response_coefficients(
     ax: plt.Axes = None,
     cax: plt.Axes = None,
 ) -> Tuple[plt.Figure, plt.Axes, QuadMesh]:
-    """Plot response of the steady state fluxes to a change of the given parameters."""
+    """Calculate and plot response of the steady state fluxes to a change of the given parameters.
+
+    See also
+    --------
+    get_flux_response_coefficients_df
+    plot_coefficient_heatmap
+    """
     df = get_flux_response_coefficients_df(
         model=model,
         parameters=parameters,
