@@ -1,13 +1,15 @@
+"""Some docstring"""
+
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Any, List, Optional
-
-import libsbml
+from typing import List, Optional
 
 
 @dataclass
 class AtomicUnit:
+    """Some docstring"""
+
     kind: str
     exponent: int
     scale: int
@@ -16,12 +18,16 @@ class AtomicUnit:
 
 @dataclass
 class CompositeUnit:
+    """Some docstring"""
+
     sbml_id: str
     units: list
 
 
 @dataclass
 class Parameter:
+    """Some docstring"""
+
     sbml_id: str
     name: str
     value: float
@@ -30,6 +36,8 @@ class Parameter:
 
 @dataclass
 class InitialAssignment:
+    """Some docstring"""
+
     sbml_id: str
     derived_parameter: str
     function_args: List[str]
@@ -39,6 +47,8 @@ class InitialAssignment:
 
 @dataclass
 class Compartment:
+    """Some docstring"""
+
     sbml_id: str
     name: str
     dimensions: int
@@ -49,6 +59,8 @@ class Compartment:
 
 @dataclass
 class Compound:
+    """Some docstring"""
+
     sbml_id: str
     name: str
     compartment: Optional[str]
@@ -62,6 +74,8 @@ class Compound:
 
 @dataclass
 class Function:
+    """Some docstring"""
+
     sbml_id: str
     name: str
     function_args: List[str]
@@ -71,6 +85,8 @@ class Function:
 
 @dataclass
 class AlgebraicRule:
+    """Some docstring"""
+
     sbml_id: str
     sbml_math: str
     parsed_args: List[str]
@@ -81,6 +97,8 @@ class AlgebraicRule:
 
 @dataclass
 class AssignmentRule:
+    """Some docstring"""
+
     sbml_id: str
     sbml_math: str
     parsed_args: List[str]
@@ -94,6 +112,8 @@ class AssignmentRule:
 
 @dataclass
 class RateRule:
+    """Some docstring"""
+
     sbml_id: str
     sbml_math: str
     parsed_args: List[str]
@@ -105,6 +125,8 @@ class RateRule:
 
 @dataclass
 class Reaction:
+    """Some docstring"""
+
     sbml_id: str
     sbml_math: str
     is_reversible: bool
