@@ -1,3 +1,5 @@
+"""Some docstring"""
+
 from __future__ import annotations
 
 from typing import List
@@ -10,22 +12,27 @@ AST_TYPES = get_ast_types()
 
 
 def handle_ast_constant_e(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return "math.e"
 
 
 def handle_ast_constant_false(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return "False"
 
 
 def handle_ast_constant_true(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return "True"
 
 
 def handle_ast_constant_pi(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return "math.pi"
 
 
 def handle_ast_divide(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -40,6 +47,7 @@ def handle_ast_divide(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_divide_int(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -54,6 +62,7 @@ def handle_ast_divide_int(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_function(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -64,45 +73,54 @@ def handle_ast_function(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_function_abs(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.abs({child})"
 
 
 def handle_ast_function_ceiling(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"math.ceil({child})"
 
 
 def handle_ast_function_delay(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     raise NotImplementedError
 
 
 def handle_ast_function_exp(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.exp({child})"
 
 
 def handle_ast_function_factorial(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"math.factorial({child})"
 
 
 def handle_ast_function_floor(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"math.floor({child})"
 
 
 def handle_ast_function_ln(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.log({child})"
 
 
 def handle_ast_function_log(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.log10({child})"
 
 
 def handle_ast_function_max(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -112,6 +130,7 @@ def handle_ast_function_max(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_function_min(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -121,6 +140,7 @@ def handle_ast_function_min(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_function_piecewise(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -130,12 +150,11 @@ def handle_ast_function_piecewise(node: ASTNode, func_arguments: List[str]) -> s
         x = children[0]
         y = children[2]
         return f"np.where({condition}, {x}, {y})"
-        # return f"({} if {} else {})"
-    else:
-        return f"({children[0]} if {children[1]})"
+    return f"({children[0]} if {children[1]})"
 
 
 def handle_ast_function_power(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -144,28 +163,24 @@ def handle_ast_function_power(node: ASTNode, func_arguments: List[str]) -> str:
     right_subchildren = node.getChild(1).getChild(0) is not None
     if left_subchildren and right_subchildren:
         return f"({children[0]}) ** ({children[1]})"
-    elif left_subchildren:
+    if left_subchildren:
         return f"({children[0]}) ** {children[1]}"
-    elif right_subchildren:
-        return f"{children[0]} ** ({children[1]})"
-    else:
-        return f"{children[0]} ** {children[1]}"
-
-    return f"{children[0]} ** {children[1]}"
-    # args = ", ".join(children)
-    # return f"np.power({args})"
+    return f"{children[0]} ** ({children[1]})"
 
 
 def handle_ast_function_rate_of(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     raise NotImplementedError
 
 
 def handle_ast_function_root(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.sqrt({child})"
 
 
 def handle_ast_function_rem(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -175,10 +190,12 @@ def handle_ast_function_rem(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_integer(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return str(int(node.getValue()))
 
 
 def handle_ast_lambda(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     num_b_vars = node.getNumBvars()
     num_children = node.getNumChildren()
     children = [
@@ -189,67 +206,69 @@ def handle_ast_lambda(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_logical_and(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
     ]
     if len(children) == 0:
         return "and"
-    elif len(children) == 1:
+    if len(children) == 1:
         return "and"
-    else:
-        args = " and ".join(children)
-        return f"({args})"
+    args = " and ".join(children)
+    return f"({args})"
 
 
 def handle_ast_logical_implies(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     raise NotImplementedError
 
 
 def handle_ast_logical_not(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
     ]
     if len(children) == 0:
         return "not"
-    elif len(children) == 1:
+    if len(children) == 1:
         return f"not({children[0]})"
-    else:
-        args = " not ".join(children)
-        return f"({args})"
+    args = " not ".join(children)
+    return f"({args})"
 
 
 def handle_ast_logical_or(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
     ]
     if len(children) == 0:
         return "or"
-    elif len(children) == 1:
+    if len(children) == 1:
         return "or"
-    else:
-        args = " or ".join(children)
-        return f"({args})"
+    args = " or ".join(children)
+    return f"({args})"
 
 
 def handle_ast_logical_xor(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
     ]
     if len(children) == 0:
         return "^"
-    elif len(children) == 1:
+    if len(children) == 1:
         return "^"
-    else:
-        children = [f"({i})" for i in children]
-        args = " ^ ".join(children)
-        return f"({args})"
+    children = [f"({i})" for i in children]
+    args = " ^ ".join(children)
+    return f"({args})"
 
 
 def handle_ast_minus(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -264,26 +283,30 @@ def handle_ast_minus(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_name(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     name: str = node.getName()
     func_arguments.append(name)
     return name
 
 
 def handle_ast_name_avogadro(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return "6.02214179e+23"
-    # return "6.02214076e+23"
 
 
 def handle_ast_name_time(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     func_arguments.append("time")
     return "time"
 
 
 def handle_ast_originates_in_package(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     raise NotImplementedError
 
 
 def handle_ast_plus(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -292,19 +315,22 @@ def handle_ast_plus(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_rational(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     return str(node.getValue())
 
 
 def handle_ast_real(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     value = str(node.getValue())
     if value == "inf":
         return "np.infty"
-    elif value == "nan":
+    if value == "nan":
         return "np.nan"
     return value
 
 
 def handle_ast_relational_eq(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -315,6 +341,7 @@ def handle_ast_relational_eq(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_relational_geq(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -325,6 +352,7 @@ def handle_ast_relational_geq(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_relational_gt(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -335,6 +363,7 @@ def handle_ast_relational_gt(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_relational_leq(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -345,6 +374,7 @@ def handle_ast_relational_leq(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_relational_lt(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -355,6 +385,7 @@ def handle_ast_relational_lt(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_relational_neq(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -365,6 +396,7 @@ def handle_ast_relational_neq(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_times(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     children = [
         handle_ast_node(node=node.getChild(i), func_arguments=func_arguments)
         for i in range(node.getNumChildren())
@@ -384,31 +416,37 @@ def handle_ast_times(node: ASTNode, func_arguments: List[str]) -> str:
 
 
 def handle_ast_trigonometric_sin(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.sin({child})"
 
 
 def handle_ast_trigonometric_cos(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.cos({child})"
 
 
 def handle_ast_trigonometric_tan(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.tan({child})"
 
 
 def handle_ast_trigonometric_sec(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.cos({child})"
 
 
 def handle_ast_trigonometric_csc(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.sin({child})"
 
 
 def handle_ast_trigonometric_cot(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.tan({child})"
 
@@ -419,31 +457,37 @@ def handle_ast_trigonometric_cot(node: ASTNode, func_arguments: List[str]) -> st
 
 
 def handle_ast_trigonometric_arc_sin(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arcsin({child})"
 
 
 def handle_ast_trigonometric_arc_cos(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arccos({child})"
 
 
 def handle_ast_trigonometric_arc_tan(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arctan({child})"
 
 
 def handle_ast_trigonometric_arc_cot(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arctan(1 / ({child}))"
 
 
 def handle_ast_trigonometric_arc_sec(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arccos(1 / ({child}))"
 
 
 def handle_ast_trigonometric_arc_csc(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arcsin(1 / ({child}))"
 
@@ -454,31 +498,37 @@ def handle_ast_trigonometric_arc_csc(node: ASTNode, func_arguments: List[str]) -
 
 
 def handle_ast_trigonometric_sinh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.sinh({child})"
 
 
 def handle_ast_trigonometric_cosh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.cosh({child})"
 
 
 def handle_ast_trigonometric_tanh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.tanh({child})"
 
 
 def handle_ast_trigonometric_sech(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.cosh({child})"
 
 
 def handle_ast_trigonometric_csch(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.sinh({child})"
 
 
 def handle_ast_trigonometric_coth(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"1 / np.tanh({child})"
 
@@ -489,36 +539,43 @@ def handle_ast_trigonometric_coth(node: ASTNode, func_arguments: List[str]) -> s
 
 
 def handle_ast_trigonometric_arc_sinh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arcsinh({child})"
 
 
 def handle_ast_trigonometric_arc_cosh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arccosh({child})"
 
 
 def handle_ast_trigonometric_arc_tanh(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arctanh({child})"
 
 
 def handle_ast_trigonometric_arc_csch(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arcsinh(1 / {child})"
 
 
 def handle_ast_trigonometric_arc_sech(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arccosh(1 / {child})"
 
 
 def handle_ast_trigonometric_arc_coth(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     child = handle_ast_node(node=node.getChild(0), func_arguments=func_arguments)
     return f"np.arctanh(1 / {child})"
 
 
 def handle_ast_node(node: ASTNode, func_arguments: List[str]) -> str:
+    """Some docstring"""
     commands = {
         "AST_CONSTANT_E": handle_ast_constant_e,
         "AST_CONSTANT_FALSE": handle_ast_constant_false,
